
const useProxy = true
const proxyUrl = useProxy ? "https://cors-proxy.r2cache.com/" : "";
const config = {
  "basePath": proxyUrl + "https://assets.demodrive.ijewel3d.com/ijewel/",
  // "model_url": "/ring.3dm",
  "model_url": "http://localhost:8449/model.3dm",
  "logo": "https://playground.ijewel3d.com/logo_black.svg",
  "sceneConfig": {
    "Environment": "presets/environment/env-metal-1.hdr",
    "GemEnvironment": "presets/environment/env-gem-4.exr",
    "Ground": "presets/ground/softshadow_backleft.json"
  },
  "labels": {
    "metal": ["Main Trim", "Shank Trim", "Side Trim", "Accent Trim", "Inlay Trim", "Lace Trim", "Halo", "Chain"],
    "gem": ["Center Gem", "Side Gem", "Accent Gem", "Inlay Gem", "Shank Gem", "Halo Gem", "Crest Gem", "Color Gem", "Fancy Gem"]
  },
  "materialConfig": {
    "materials": [
      { "name": "Metal", "path": "materials/metal/gold-yellow-750.pmat" },
      { "name": "Metal 01", "path": "materials/metal/gold-white-750.pmat" },
      { "name": "Metal 02", "path": "materials/metal/gold-rose-750.pmat" },
      { "name": "Metal 03", "path": "materials/metal/gold-rose-750.pmat" },
      { "name": "Metal 04", "path": "materials/metal/gold-rose-750.pmat" },
      { "name": "Head", "path": "materials/metal/gold-rose-750.pmat" },
      { "name": "Gem", "path": "materials/gem/diamond-white-1.dmat" },
      { "name": "Gem 01", "path": "materials/gem/diamond-white-1.dmat" },
      { "name": "Gem 02", "path": "materials/gem/diamond-white-1.dmat" },
      { "name": "Gem 03", "path": "materials/gem/diamond-white-1.dmat" },
      { "name": "Gem 04", "path": "materials/gem/diamond-white-1.dmat" },
      { "name": "Heads", "path": "materials/metal/gold-white-750.pmat" }
    ],
    "type": "MaterialPresetPlugin"
  },
  "configuratorConfig": [
    {
      "name": "Metal",
      "title": "Gold",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Metal 01",
      "title": "Shank",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" },
        { "name": "platinum-950.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Metal 02",
      "title": "Metal 02",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" },
        { "name": "platinum-950.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Metal 03",
      "title": "Metal 03",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" },
        { "name": "platinum-950.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Metal 04",
      "title": "Metal 04",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" },
        { "name": "platinum-950.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Heads",
      "title": "Head",
      "options": [
        { "name": "gold-white-750.pmat", "type": "metal" },
        { "name": "gold-yellow-750.pmat", "type": "metal" },
        { "name": "gold-rose-750.pmat", "type": "metal" },
        { "name": "platinum-950.pmat", "type": "metal" }
      ]
    },
    {
      "name": "Gem",
      "title": "Center Diamond",
      "options": [
        { "name": "diamond-white-1.dmat", "type": "gem" },
        { "name": "ruby-1.dmat", "type": "gem" },
        { "name": "sapphire-1.dmat", "type": "gem" }
      ]
    },
    {
      "name": "Gem 01",
      "title": "Side Stone",
      "options": [
        { "name": "diamond-white-1.dmat", "type": "gem" },
        { "name": "ruby-1.dmat", "type": "gem" },
        { "name": "sapphire-1.dmat", "type": "gem" },
        { "name": "emerald-1.dmat", "type": "gem" }
      ]
    },
    {
      "name": "Gem 02",
      "title": "Band Stone",
      "options": [
        { "name": "diamond-white-1.dmat", "type": "gem" },
        { "name": "ruby-1.dmat", "type": "gem" },
        { "name": "sapphire-1.dmat", "type": "gem" },
        { "name": "emerald-1.dmat", "type": "gem" }
      ]
    },
    {
      "name": "Gem 03",
      "title": "Side Stone",
      "options": [
        { "name": "diamond-white-1.dmat", "type": "gem" },
        { "name": "ruby-1.dmat", "type": "gem" },
        { "name": "sapphire-1.dmat", "type": "gem" },
        { "name": "emerald-1.dmat", "type": "gem" }
      ]
    }
  ]
};

let getConfig = {}

const editorSettings = {
  allow3dExport: true,
  hideLogoInput: true,
  hideSaveButton: true,
  saveCallback: (updatedConfig) => {
    console.log("Updated configuration:", updatedConfig);
    getConfig = updatedConfig
  },
};

window.addEventListener('webgi-viewer-ready', async (ev) => {
  const viewer = ev.detail.viewer;

  viewer.scene.addEventListener("addSceneObject", async (e) => {

  })

  document.getElementById('share-btn').addEventListener('click', async (event) => {
    const exporterPlugin = await viewer.getPluginByType("AssetExporterPlugin");
    exporterPlugin.exportOptions.encrypt = document.getElementById('encrypt-btn').classList.contains('active');
    if(exporterPlugin.exportOptions.encrypt) {
      const key = prompt('Enter a password to encrypt the 3D Model. This file can only be viewed with the password', exporterPlugin.exportOptions.encryptKey)
      if (key) {
        exporterPlugin.exportOptions.encryptKey = key
      }else {
        const cont = confirm('Export file without a password?')
        if(!cont) {
          return
        }
        exporterPlugin.exportOptions.encrypt = false
        document.getElementById('encrypt-btn').classList.remove('active');
      }
    }

    const editorPlugin = await viewer.getPluginByType("IjewelEditorPlugin");
    event.target.disabled = true;
    event.target.innerHTML = 'Uploading...';
    document.getElementById('upload-spinner').style.display = 'block';
    console.log('Starting file export');

    const blob = await editorPlugin.export(true, true, false)

    console.log('File Exported:', blob);

    console.log('Starting upload');
    const resp = await fetch('https://bee.transfr.one/file.glb', {
      method: 'PUT',
      body: new File([blob], 'file.glb')
    });
    console.log('Upload response:', resp);

    if (resp.status !== 200) {
      return alert('Unable to upload file, check your internet connection and try again.');
    }

    const model_url = await resp.text();

    // Extract IDs from URLs
    const modelId = model_url.split('/').slice(-2).join('-').replace('-file.glb', '');

    const fullUrl = `https://ijewel.design/rhino?m=${modelId}`;
    console.log('Full URL:', fullUrl);
    window.open(fullUrl)

    event.target.disabled = false;
    event.target.innerHTML = 'Share';
    document.getElementById('upload-spinner').style.display = 'none';
  })
})

new ijewelEditor.MiniEditor(document.getElementById("root"), config, editorSettings);
